==> openshift-serverless-logic-1.26.0-src.zip: openshift-serverless-logic-1.26.0.GA-src/org.kie.kogito-kogito-apps-1.30.0.Final/ui-packages/packages/process-form/src/envelope/tests/ProcessFormEnvelopeViewDriver.test.ts <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {
  MessageBusClientApi,
  RequestPropertyNames
} from '@kogito-tooling/envelope-bus/dist/api';
import { ProcessFormChannelApi } from '../../api';
import { ProcessFormEnvelopeViewDriver } from '../ProcessFormEnvelopeViewDriver';
import { MockedMessageBusClientApi } from './mocks/Mocks';

let channelApi: MessageBusClientApi<ProcessFormChannelApi>;
let requests: Pick<
  ProcessFormChannelApi,
  RequestPropertyNames<ProcessFormChannelApi>
>;
let driver: ProcessFormEnvelopeViewDriver;

describe('ProcessFormEnvelopeViewDriver tests', () => {
  beforeEach(() => {
    jest.clearAllMocks();
    channelApi = new MockedMessageBusClientApi();
    requests = channelApi.requests;
    driver = new ProcessFormEnvelopeViewDriver(channelApi);
  });

  it('getProcessFormSchema', () => {
    const processDefinitionData = {
      processName: 'process1',
      endpoint: 'http://localhost:4000'
    };
    driver.getProcessFormSchema(processDefinitionData);

    expect(requests.processForm__getProcessFormSchema).toHaveBeenCalledWith(
      processDefinitionData
    );
  });

  it('doSubmit', () => {
    const formJSON = {
      something: 'something'
    };
    driver.startProcess(formJSON);

    expect(requests.processForm__startProcess).toHaveBeenCalledWith(formJSON);
  });
});

==> openshift-serverless-logic-1.31.0-src.zip: openshift-serverless-logic-1.31.0.GA-src/org.kie.kogito-kogito-apps-1.44.0.Final/ui-packages/packages/process-form/src/envelope/tests/ProcessFormEnvelopeViewDriver.test.ts <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {
  MessageBusClientApi,
  RequestPropertyNames
} from '@kie-tools-core/envelope-bus/dist/api';
import { ProcessFormChannelApi } from '../../api';
import { ProcessFormEnvelopeViewDriver } from '../ProcessFormEnvelopeViewDriver';
import { MockedMessageBusClientApi } from './mocks/Mocks';

let channelApi: MessageBusClientApi<ProcessFormChannelApi>;
let requests: Pick<
  ProcessFormChannelApi,
  RequestPropertyNames<ProcessFormChannelApi>
>;
let driver: ProcessFormEnvelopeViewDriver;

describe('ProcessFormEnvelopeViewDriver tests', () => {
  beforeEach(() => {
    jest.clearAllMocks();
    channelApi = new MockedMessageBusClientApi();
    requests = channelApi.requests;
    driver = new ProcessFormEnvelopeViewDriver(channelApi);
  });

  it('getProcessFormSchema', () => {
    const processDefinitionData = {
      processName: 'process1',
      endpoint: 'http://localhost:4000'
    };
    driver.getProcessFormSchema(processDefinitionData);

    expect(requests.processForm__getProcessFormSchema).toHaveBeenCalledWith(
      processDefinitionData
    );
  });

  it('doSubmit', () => {
    const formJSON = {
      something: 'something'
    };
    driver.startProcess(formJSON);

    expect(requests.processForm__startProcess).toHaveBeenCalledWith(formJSON);
  });
});
